==> lxqt-session_1.1.1.orig.tar.xz: lxqt-session-1.1.1/lxqt-config-session/translations/lxqt-config-session_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Αναζήτηση...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Εντολή:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Αναμονή για το πλαίσιο συστήματος</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Επιλογή εφαρμογής</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Καθολική αυτόματη εκκίνηση</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Αυτόματη εκκίνηση LXQt</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Τοποθεσία: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Αντικατάσταση: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Αυτόματη εκκίνηση εφαρμογής</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Το αρχείο «%1» υπάρχει ήδη!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Διαχειριστής παραθύρων</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Αναζήτηση...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Αρθρώματα LXQt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Global Screen Scaling</source>
        <translation>Καθολική κλιμάκωση της οθόνης</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="123"/>
        <source>Scale factor:</source>
        <translation>Συντελεστής κλιμάκωσης:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="149"/>
        <source>Leave Session</source>
        <translation>Εγκατάλειψη της συνεδρίας</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="155"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Ερώτηση επιβεβαίωσης κατά την εγκατάλειψη της συνεδρίας</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="162"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Κλείδωμα της οθόνης πριν την αναστολή/νάρκη</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="169"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Αναστολή/νάρκωση μετά από το χρονικό διάστημα κλειδώματος:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="182"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Βασικές ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Εκκίνηση</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="176"/>
        <source>Select a window manager</source>
        <translation>Επιλογή διαχειριστή παραθύρων</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Μεταβλητές περιβάλλοντος (για προχωρημένους)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Όνομα μεταβλητής</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Τιμή</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Εκτελείται</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>Ρυθμίσεις συνεδρίας LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Βασικές ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>Κατάλογοι του χρήστη</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>Αυτόματη εκκίνηση</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>Περιβάλλον (για προχωρημένους)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="91"/>
        <source>Session Restart Required</source>
        <translation>Απαιτείται επανεκκίνηση συνεδρίας</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Μερικές ρυθμίσεις λαμβάνουν χώρα μετά από επανασύνδεση.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Τοποθεσίες των προσωπικών αρχείων</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Ρυθμίσεις συνεδρίας LXQt - Κατάλογοι του χρήστη</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>Παρουσιάστηκε ένα σφάλμα κατά την εφαρμογή των ρυθμίσεων για την τοποθεσία %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Επιλογή τοποθεσίας</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Πρότυπα</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Δημόσια κοινή χρήση</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Έγγραφα</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Περιέχει όλα τα αρχεία που βλέπετε στην επιφάνεια εργασίας σας</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Ο εξ ορισμού φάκελος αποθήκευσης των ειλημμένων αρχείων</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Ο εξ ορισμού φάκελος φόρτωσης ή αποθήκευσης των προτύπων</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Ο εξ ορισμού φάκελος κοινής χρήσης των αρχείων σας</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Ο εξ ορισμού φάκελος φόρτωσης ή αποθήκευσης των εγγράφων</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Ο εξ ορισμού φάκελος φόρτωσης ή αποθήκευσης της μουσικής</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Ο εξ ορισμού φάκελος φόρτωσης ή αποθήκευσης των εικόνων</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Ο εξ ορισμού φάκελος φόρτωσης ή αποθήκευσης των βίντεο</translation>
    </message>
</context>
</TS>

==> lxqt-session_2.1.0.orig.tar.xz: lxqt-session-2.1.0/lxqt-config-session/translations/lxqt-config-session_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Όνομα:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="40"/>
        <source>Search...</source>
        <translation>Αναζήτηση...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="54"/>
        <source>Start only in X11</source>
        <translation>Εκκίνηση μόνο σε X11</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="30"/>
        <source>Command:</source>
        <translation>Εντολή:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Wait for system tray</source>
        <translation>Αναμονή για το πλαίσιο συστήματος</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="67"/>
        <source>Select Application</source>
        <translation>Επιλογή εφαρμογής</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Καθολική αυτόματη εκκίνηση</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Αυτόματη εκκίνηση LXQt</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Τοποθεσία: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Αντικατάσταση: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Επεξεργασία</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Αυτόματη εκκίνηση εφαρμογής</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="151"/>
        <location filename="../autostartpage.cpp" line="170"/>
        <location filename="../autostartpage.cpp" line="187"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="140"/>
        <location filename="../autostartpage.cpp" line="170"/>
        <source>Please provide Name and Command</source>
        <translation>Παρακαλώ καθορίστε το όνομα και την εντολή</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="151"/>
        <location filename="../autostartpage.cpp" line="187"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>Το αρχείο «%1» υπάρχει ήδη!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Διαχειριστής παραθύρων</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <location filename="../basicsettings.ui" line="213"/>
        <source>Search...</source>
        <translation>Αναζήτηση...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Αρθρώματα LXQt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Under Wayland, adjust scaling via compositor settings or kanshi instead.</source>
        <translation>Στο Wayland, ρυθμίστε την κλιμάκωση μέσω των ρυθμίσεων συνθέτη ή εναλλακτικά του kanshi.</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="114"/>
        <source>Global Screen Scaling</source>
        <translation>Καθολική κλιμάκωση της οθόνης</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="126"/>
        <source>Scale factor:</source>
        <translation>Συντελεστής κλιμάκωσης:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="152"/>
        <source>Leave Session</source>
        <translation>Εγκατάλειψη της συνεδρίας</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="158"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Ερώτηση επιβεβαίωσης κατά την εγκατάλειψη της συνεδρίας</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="165"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Κλείδωμα της οθόνης πριν την αναστολή/νάρκη</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="172"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Αναστολή/νάρκωση μετά από το χρονικό διάστημα κλειδώματος:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="185"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="201"/>
        <source>Use custom screen lock command</source>
        <translation>Χρήση προσαρμοσμένης εντολής κλειδώματος της οθόνης</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Βασικές ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Εκκίνηση</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="197"/>
        <source>Select a window manager</source>
        <translation>Επιλογή διαχειριστή παραθύρων</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="212"/>
        <source>Select a screenlocker</source>
        <translation>Επιλέξτε το κλείδωμα οθόνης</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Προσθήκη</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Μεταβλητές περιβάλλοντος (για προχωρημένους)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Όνομα μεταβλητής</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Τιμή</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Εκτελείται</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="45"/>
        <source>LXQt Session Settings</source>
        <translation>Ρυθμίσεις συνεδρίας LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="48"/>
        <source>Basic Settings</source>
        <translation>Βασικές ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="54"/>
        <source>User Directories</source>
        <translation>Κατάλογοι του χρήστη</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="60"/>
        <source>Autostart</source>
        <translation>Αυτόματη εκκίνηση</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="67"/>
        <source>Wayland Settings (Experimental)</source>
        <translation>Ρυθμίσεις Wayland (πειραματικό)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="74"/>
        <source>Environment (Advanced)</source>
        <translation>Περιβάλλον (για προχωρημένους)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="100"/>
        <source>Session Restart Required</source>
        <translation>Απαιτείται επανεκκίνηση συνεδρίας</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="101"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Μερικές ρυθμίσεις λαμβάνουν χώρα μετά από επανασύνδεση.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Τοποθεσίες των προσωπικών αρχείων</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Ρυθμίσεις συνεδρίας LXQt - Κατάλογοι του χρήστη</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error occurred while applying the settings for the %1 location</source>
        <translation>Παρουσιάστηκε ένα σφάλμα κατά την εφαρμογή των ρυθμίσεων για την τοποθεσία %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Επιλογή τοποθεσίας</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Λήψεις</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Πρότυπα</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Δημόσια κοινή χρήση</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Έγγραφα</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Μουσική</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Βίντεο</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Περιέχει όλα τα αρχεία που βλέπετε στην επιφάνεια εργασίας σας</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Ο εξ ορισμού φάκελος αποθήκευσης των ειλημμένων αρχείων</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Ο εξ ορισμού φάκελος φόρτωσης ή αποθήκευσης των προτύπων</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Ο εξ ορισμού φάκελος κοινής χρήσης των αρχείων σας</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Ο εξ ορισμού φάκελος φόρτωσης ή αποθήκευσης των εγγράφων</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Ο εξ ορισμού φάκελος φόρτωσης ή αποθήκευσης της μουσικής</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Ο εξ ορισμού φάκελος φόρτωσης ή αποθήκευσης των εικόνων</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Ο εξ ορισμού φάκελος φόρτωσης ή αποθήκευσης των βίντεο</translation>
    </message>
</context>
<context>
    <name>WaylandSettings</name>
    <message>
        <location filename="../waylandsettings.ui" line="23"/>
        <source>Wayland Settings</source>
        <translation>Ρυθμίσεις Wayland</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="30"/>
        <source>Wayland compositor:</source>
        <translation>Συνθέτης Wayland:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="49"/>
        <location filename="../waylandsettings.ui" line="81"/>
        <source>Search...</source>
        <translation>Αναζήτηση...</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="59"/>
        <source>Screenlock command:</source>
        <translation>Εντολή κλειδώματος οθόνης:</translation>
    </message>
    <message>
        <location filename="../waylandsettings.ui" line="71"/>
        <source>Use &quot;loginctl lock-session&quot; on kwin_wayland</source>
        <translation>Χρήση &quot;loginctl lock-session&quot; σε kwin_wayland</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="98"/>
        <source>Select a Wayland Compositor</source>
        <translation>Επιλογή ενός συνθέτη Wayland</translation>
    </message>
    <message>
        <location filename="../waylandsettings.cpp" line="103"/>
        <source>Select a Screenlocker for Wayland</source>
        <translation>Επιλογή ενός κλειδώματος οθόνης για το Wayland</translation>
    </message>
</context>
</TS>
